from distutils.core import setup
from glob import glob
from distutils.command.install_data import install_data
from distutils.command.build import build 
from distutils.dep_util import newer
from distutils.log import warn, info, error, fatal
import os, sys, subprocess
from setuptools import setup, find_packages

version = '0.17.0'

"""os.chdir(os.path.abspath(os.path.dirname(__file__)))"""

PO_DIR = 'po'
MO_DIR = os.path.join('build','mo')

class build_py(build):
    def run (self):
        build.run (self)

        #if self.distribution.without_gettext:
        #    return

        for po in glob (os.path.join (PO_DIR, '*.po')):
            lang = os.path.basename(po[:-3])
            mo = os.path.join(MO_DIR, lang, 'timeline.mo')

            directory = os.path.dirname(mo)
            if not os.path.exists(directory):
                info('creating %s' % directory)
                os.makedirs(directory)

            if newer(po, mo):
                info('compiling %s -> %s' % (po, mo))
                try:
                    rc = subprocess.call(['msgfmt', '-o', mo, po])
                    if rc != 0:
                        raise Warning, "msgfmt returned %d" % rc
                except Exception, e:
                    error("Building gettext files failed.  Try setup.py --without-gettext [build|install]")
                    error("Error: %s" % str(e))
                    sys.exit(1)

        TOP_BUILDDIR='.'
        INTLTOOL_MERGE='intltool-merge'


class InstallData(install_data):
    def run (self):
        self.data_files.extend (self._find_mo_files ())
        install_data.run (self)
        """
	#if not self.distribution.without_icon_cache:
        #    self._update_icon_cache ()
        for path in self.get_outputs():
            if path.endswith ('share/applications/timeline.desktop'):
                #Install the indicator file
                try:
                    f = open ('/usr/share/indicators/messages/applications/timeline', 'w')
                    f.write (path + '\n')
                    f.close()
                except Exception:
                    warn("Cannot create the indicator file")
        """ 

    def _find_mo_files (self):
        data_files = []

        if True: #if not self.distribution.without_gettext:
            for mo in glob (os.path.join (MO_DIR, '*', 'timeline.mo')):
                lang = os.path.basename(os.path.dirname(mo))
                dest = os.path.join('share', 'locale', lang, 'LC_MESSAGES')
                data_files.append((dest, [mo]))

        return data_files
        
README = os.path.join(os.path.dirname(__file__), 'README')

long_description = open(README).read() + 'nn'

setup(name='timeline',
      version=version,
      author='soportelihuen',
      author_email='soportelihuen@mail.linti.unlp.edu.ar',
      url='http://www.lihuen.linti.unlp.edu.ar',
      license='GPL',
      scripts=['timelineLaunch','timeline.py'],
      packages=find_packages(),
      include_package_data=True,
      cmdclass={'build': build_py, 'install_data': InstallData}      
)
